:github_url: https://github.com/tasts-robots/pink/tree/master/doc/src/tasks.rst

.. _Tasks:

*****
Tasks
*****

Base task
=========

.. automodule:: pink.tasks.task
    :members:

Body task
=========

.. automodule:: pink.tasks.body_task
    :members:

Joint coupling task
===================

.. automodule:: pink.tasks.joint_coupling_task
    :members:

Linear holonomic task
=====================

.. automodule:: pink.tasks.linear_holonomic_task
    :members:

Posture task
============

.. automodule:: pink.tasks.posture_task
    :members:
